@@ -9,4 +9,5 @@
 import django.dispatch
 
 
-topic_viewed = django.dispatch.Signal(providing_args=["topic", "user", "request", "response", ])
+# "topic", "user", "request", "response"
+topic_viewed = django.dispatch.Signal()
