@@ -1,4 +1,5 @@
 import factory
+import factory.django
 from faker import Faker
 
 from machina.core.db.models import get_model
@@ -10,9 +11,10 @@ faker = Faker()
 Attachment = get_model('forum_attachments', 'Attachment')
 
 
-class AttachmentFactory(factory.DjangoModelFactory):
+class AttachmentFactory(factory.django.DjangoModelFactory):
     post = factory.SubFactory(PostFactory)
     comment = faker.text(max_nb_chars=255)
+    file = factory.django.FileField()
 
     class Meta:
         model = Attachment
