@@ -1,4 +1,5 @@
 import factory
+import factory.django
 from django.contrib.auth.models import Group, User
 from faker import Faker
 
@@ -6,7 +7,7 @@ from faker import Faker
 faker = Faker()
 
 
-class UserFactory(factory.DjangoModelFactory):
+class UserFactory(factory.django.DjangoModelFactory):
     username = factory.Sequence(lambda n: '{}-{}'.format(faker.user_name(), n))
     email = factory.Sequence(lambda n: 'test{0}@example.com'.format(n))
     password = '1234'
@@ -26,7 +27,7 @@ class UserFactory(factory.DjangoModelFactory):
         return user
 
 
-class GroupFactory(factory.DjangoModelFactory):
+class GroupFactory(factory.django.DjangoModelFactory):
     name = factory.Sequence(lambda n: '{}-{}'.format(str(n), faker.job()))
 
     class Meta:
