@@ -1,4 +1,5 @@
 import factory
+import factory.django
 from faker import Faker
 
 from machina.core.db.models import get_model
@@ -13,7 +14,7 @@ TopicPollOption = get_model('forum_polls', 'TopicPollOption')
 TopicPollVote = get_model('forum_polls', 'TopicPollVote')
 
 
-class TopicPollFactory(factory.DjangoModelFactory):
+class TopicPollFactory(factory.django.DjangoModelFactory):
     topic = factory.SubFactory(TopicFactory)
     question = faker.text(max_nb_chars=200)
 
@@ -21,7 +22,7 @@ class TopicPollFactory(factory.DjangoModelFactory):
         model = TopicPoll
 
 
-class TopicPollOptionFactory(factory.DjangoModelFactory):
+class TopicPollOptionFactory(factory.django.DjangoModelFactory):
     poll = factory.SubFactory(TopicPollFactory)
     text = faker.text(max_nb_chars=100)
 
@@ -29,7 +30,7 @@ class TopicPollOptionFactory(factory.DjangoModelFactory):
         model = TopicPollOption
 
 
-class TopicPollVoteFactory(factory.DjangoModelFactory):
+class TopicPollVoteFactory(factory.django.DjangoModelFactory):
     poll_option = factory.SubFactory(TopicPollOptionFactory)
     voter = factory.SubFactory(UserFactory)
 
